/* --COPYRIGHT--,BSD
 * Copyright (c) 2016, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * --/COPYRIGHT--*/
//############################################################################
//
//! \file   user_command.h
//!
//! \brief  Driver for the touch functions
//
//  Target Device:  MSP430FR2633
//
//  Created on: July, 2015
//  Author: a0222599
//############################################################################
#ifndef __USER_COMMAND_H__
#define __USER_COMMAND_H__

//****************************************************************************
// the includes
//****************************************************************************
#include <msp430.h>

//****************************************************************************
//
// If building with a C++ compiler, make all of the definitions in this header
// have a C binding.
//
//****************************************************************************
#ifdef __cplusplus
extern "C"
{
#endif

//****************************************************************************
//defines
//****************************************************************************
//! \command protocol
//!
//    16bits command of 0xXXXX
//    bit[15:12] : Direction of command
//        0x0 ----- touch module to Host
//        0x1 ----- Host to touch module
//    bit[11:8] : Type of touch
//        0x1 ----- centralpad single touch
//        0x2 ----- centralpad multi touch
//        0x3 ----- Button touch
//        0x4 ----- Slider step touch
//        0x5 ----- Slider continuous touch
//        0x6 ----- ProxPad touch
//    bit[7:0] : Touch command
//        0x1X ----- fingure straight slide
//        0x2X ----- fingure tap
//        0xXX ----- slider continuous position
//        0x3X ----- slider step up
//        0x4X ----- slider step down
//        0x0X ----- button tap
//
//    0x0FFF ----- Error
//    0x0000 ----- no touch
/**************touch module --> host**************/
// central pad
/*centralpad single touch*/
#define         GESTUREPAD_SLIDE_UP                 (0x0111)
#define         GESTUREPAD_SLIDE_DOWN               (0x0112)
#define         GESTUREPAD_SLIDE_LEFT               (0x0113)
#define         GESTUREPAD_SLIDE_RIGHT              (0x0114)
#define         CENTRALPAD_ONE_TAP_SINGLE           (0x0121)
#define         CENTRALPAD_ONE_TAP_DOUBLE           (0x0122)
#define         CENTRALPAD_ONE_TAP_HOLD             (0x0123)
#define         CENTRALPAD_ONE_TAP_SINGLE_HOLD      (0x0124)
/*centralpad multi touch*/
#define         CENTRALPAD_TWO_SLIDER_UP            (0x0211)
#define         CENTRALPAD_TWO_SLIDER_DOWN          (0x0212)
#define         CENTRALPAD_TWO_SLIDER_LEFT          (0x0213)
#define         CENTRALPAD_TWO_SLIDER_RIGHT         (0x0214)
#define         CENTRALPAD_TWO_TAP_SINGLE           (0x0221)
#define         CENTRALPAD_TWO_TAP_DOUBLE           (0x0222)
#define         CENTRALPAD_TWO_TAP_HOLD             (0x0223)
#define         CENTRALPAD_TWO_TAP_SINGLE_HOLD      (0x0224)

// Buttons
#define         BUTTON_POWER                        (0x0300)
#define         BUTTON_CHUP                         (0x0301)
#define         BUTTON_CHDOWN                       (0x0302)
#define         BUTTON_A                            (0x0303)
#define         BUTTON_B                            (0x0304)
#define         BUTTON_C                            (0x0305)
#define         BUTTON_INPUT                        (0x0306)
#define         BUTTON_MUTE                         (0x0307)

// Slider
/*slider step touch*/
#define         SLIDER_VOL_UP_01                    (0x0431)
#define         SLIDER_VOL_UP_02                    (0x0432)
#define         SLIDER_VOL_UP_03                    (0x0433)
#define         SLIDER_VOL_UP_04                    (0x0434)
#define         SLIDER_VOL_UP_05                    (0x0435)
#define         SLIDER_VOL_DOWN_01                  (0x0441)
#define         SLIDER_VOL_DOWN_02                  (0x0442)
#define         SLIDER_VOL_DOWN_03                  (0x0443)
#define         SLIDER_VOL_DOWN_04                  (0x0444)
#define         SLIDER_VOL_DOWN_05                  (0x0445)
#define         SLIDER_VOL_STOP                     (0x0400)
/*slider continuous touch*/
#define         SLIDER_VOL_CONTI_BASE               (0x0500)

// ProxPad
#define         PROXPAD_WAKEUP                      (0x0601)
#define         PROXPAD_HOLD                        (0x0602)
#define         PROXPAD_NULL                        (0x0600)

// Common
#define         TOUCH_ERROR                         (0x0FFF)
#define         TOUCH_NULL                          (0x0000)



//****************************************************************************
// the function prototypes
//****************************************************************************

//! \brief         send out the command
//! \param[in] uint16_t command
extern void USER_sendCommand(uint16_t ui16command);

//****************************************************************************
//
// Mark the end of the C bindings section for C++ compilers.
//
//****************************************************************************
#ifdef __cplusplus
}
#endif

#endif  // end of __USER_COMMAND_H__ definition
