/* --COPYRIGHT--,BSD
 * Copyright (c) 2015, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * --/COPYRIGHT--*/
//############################################################################
//
//! \file   hal_led.h
//!
//! \brief  Driver for the LED
//
//  Target Device:  MSP430FR2633
//
//  Created on: July, 2015
//  Author: a0222599
//############################################################################
#ifndef __HAL_LED_H__
#define __HAL_LED_H__

//****************************************************************************
// the includes
//****************************************************************************
#include <msp430.h>
#include <stdint.h>
#include <stdbool.h>

//****************************************************************************
//
// If building with a C++ compiler, make all of the definitions in this header
// have a C binding.
//
//****************************************************************************
#ifdef __cplusplus
extern "C"
{
#endif

//****************************************************************************
//defines
//****************************************************************************
//! \brief Common defination
#define LED_BLINK_OFF_TIME    (2000000)
#define LED_BLINK_ON_TIME     (4000000)
//! \brief Green LED --> D1 --> P1.6
//!
#define LED_GREEN_POUT    (P1OUT)
#define LED_GREEN_PDIR    (P1DIR)
#define LED_GREEN_PIN     (BIT6)
#define LED_GREEN_ON      (LED_GREEN_POUT |= LED_GREEN_PIN)
#define LED_GREEN_OFF     (LED_GREEN_POUT &= ~LED_GREEN_PIN)
#define LED_GREEN_TOGGLE  (LED_GREEN_POUT ^= LED_GREEN_PIN)

//! \brief Red LED --> D2 --> P1.7
//!
#define LED_RED_POUT      (P1OUT)
#define LED_RED_PDIR      (P1DIR)
#define LED_RED_PIN       (BIT7)
#define LED_RED_ON        (LED_RED_POUT |= LED_RED_PIN)
#define LED_RED_OFF       (LED_RED_POUT &= ~LED_RED_PIN)
#define LED_RED_TOGGLE    (LED_RED_POUT ^= LED_RED_PIN)



//****************************************************************************
// the function prototypes
//****************************************************************************

//! \brief         LEDs initialize
//! \param[in] N/A
extern void USER_halLEDInit(void);


//****************************************************************************
//
// Mark the end of the C bindings section for C++ compilers.
//
//****************************************************************************
#ifdef __cplusplus
}
#endif

#endif  // end of __HAL_LED_H__ definition
