/* --COPYRIGHT--,BSD
 * Copyright (c) 2015, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * --/COPYRIGHT--*/
//############################################################################
//
//! \file   hal_timer.c
//!
//! \brief  configuration timer
//
//  Target Device:  MSP430FR2633
//
//  Created on: July, 2015
//  Author: a0222599
//############################################################################
//****************************************************************************
// the includes
//****************************************************************************
#include "hal_timer.h"
#include "touch_centralpad.h"
#include "touch.h"
#include "hal_led.h"


//****************************************************************************
// globals
//****************************************************************************
bool bTimer2Active = false;

//****************************************************************************
// function
//****************************************************************************
void USER_halTimer2Init(void)
{
    TA2CCTL0 = CCIE;                             // TACCR0 interrupt enabled
    TA2CCR0 = TA2_CCR0;
    TA2CTL = TA2_CLOCK_DIVIDER | TA2_CLOCK_SOURCE;
}//end of USER_halTimer2Init(void) function

uint16_t USER_halTimer2Start(void)
{
    TA2CTL |= TACLR;
    uint16_t ui16Counter_temp = TA2R;
    TA2CTL |= MC__CONTINUOUS;
    bTimer2Active = true;
    return ui16Counter_temp;
}// end of USER_halTimer2Start(void) function

uint16_t USER_halTimer2Stop(void)
{
    TA2CTL &= ~MC_3;
    bTimer2Active = false;
    uint16_t ui16Counter_temp = TA2R;
    TA2CTL |= TACLR;
    return ui16Counter_temp;
}// end of USER_halTimer2Stop(void) function

uint16_t USER_halTimer2GetCount(void)
{
    bTimer2Active = true;
    uint16_t ui16Counter_temp = TA2R;
    return ui16Counter_temp;
}// end of USER_halTimer2GetCount(void) function

void USER_halTimer3Init(void)
{
    TA3CCTL0 = CCIE;                             // TACCR0 interrupt enabled
    TA3CCR0 = TA3_CCR0;
    TA3CTL = TA3_CLOCK_DIVIDER | TA3_CLOCK_SOURCE;
}//end of USER_halTimer3Init(void) function

void USER_halTimer3Start(void)
{
    TA3CTL |= TACLR;
    TA3CTL |= MC__CONTINUOUS;
}// end of USER_halTimer3Start(void) function

//****************************************************************************
// Timer A2 interrupt service routine
//****************************************************************************
#if defined(__TI_COMPILER_VERSION__) || defined(__IAR_SYSTEMS_ICC__)
#pragma vector = TIMER2_A0_VECTOR
__interrupt void Timer2_A0_ISR(void)
#elif defined(__GNUC__)
void __attribute__ ((interrupt(TIMER2_A0_VECTOR))) Timer2_A0_ISR (void)
#else
#error Compiler not supported!
#endif
{
    USER_cleanTouchHistory();
    TA2CTL &= ~MC_3;
    bTimer2Active = false;
    TA2CTL |= TACLR;
}

//****************************************************************************
// Timer A3 interrupt service routine
//****************************************************************************
#if defined(__TI_COMPILER_VERSION__) || defined(__IAR_SYSTEMS_ICC__)
#pragma vector = TIMER3_A0_VECTOR
__interrupt void Timer3_A0_ISR(void)
#elif defined(__GNUC__)
void __attribute__ ((interrupt(TIMER3_A0_VECTOR))) Timer3_A0_ISR (void)
#else
#error Compiler not supported!
#endif
{
    LED_RED_OFF;
    TA3CTL &= ~MC_3;
    TA3CTL |= TACLR;
}

//****************************************************************************
// the END
//****************************************************************************
