/* --COPYRIGHT--,BSD
 * Copyright (c) 2015, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * --/COPYRIGHT--*/
//############################################################################
//
//! \file   hal_timer.h
//!
//! \brief  Driver for configuration timer
//
//  Target Device:  MSP430FR2633
//
//  Created on: July, 2015
//  Author: a0222599
//############################################################################
#ifndef __HAL_TIMER_H__
#define __HAL_TIMER_H__

//****************************************************************************
// the includes
//****************************************************************************
#include <msp430.h>
#include <stdint.h>
#include <stdbool.h>

//****************************************************************************
//
// If building with a C++ compiler, make all of the definitions in this header
// have a C binding.
//
//****************************************************************************
#ifdef __cplusplus
extern "C"
{
#endif

//****************************************************************************
//defines
//****************************************************************************
//! \Clock parameter
//#define  TA2_CLOCK_FREQUENCY                (32768)

//! \Timer2 configuration
//!
#define  TA2_CLOCK_SOURCE                   (TASSEL__ACLK)
#define  TA2_CLOCK_DIVIDER                  (ID__2)
#define  TA2_CCR0                           (32768)

//! \Timer3 configuration
//!
#define  TA3_CLOCK_SOURCE                   (TASSEL__ACLK)
#define  TA3_CLOCK_DIVIDER                  (ID__2)
#define  TA3_CCR0                           (2048)// 1/8s

//****************************************************************************
// globals
//****************************************************************************
extern bool bTimer2Active;

//****************************************************************************
// the function prototypes
//****************************************************************************

//! \brief         Inlitialize Timer_A2
//! \param[in] void
extern void USER_halTimer2Init(void);

//! \brief         Start Timer_A2
//! \param[in] void
extern uint16_t USER_halTimer2Start(void);

//! \brief         Stop Timer_A2
//! \param[in] void
extern uint16_t USER_halTimer2Stop(void);

//! \brief         Get count of Timer_A2
//! \param[in] void
extern uint16_t USER_halTimer2GetCount(void);

//! \brief         Inlitialize Timer_A3
//! \param[in] void
extern void USER_halTimer3Init(void);

//! \brief         Start Timer_A3
//! \param[in] void
extern void USER_halTimer3Start(void);

//****************************************************************************
//
// Mark the end of the C bindings section for C++ compilers.
//
//****************************************************************************
#ifdef __cplusplus
}
#endif

#endif  // end of __HAL_TIMER_H__ definition
