/* --COPYRIGHT--,BSD
 * Copyright (c) 2015, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * --/COPYRIGHT--*/
//############################################################################
//
//! \file   hal_uart.c
//!
//! \brief  configuration uart
//
//  Target Device:  MSP430FR2633
//
//  Created on: July, 2015
//  Author: a0222599
//  Modified on: Dec. 2015, add UARTA0 for GesturePad support by a0222599
//############################################################################
//****************************************************************************
// the includes
//****************************************************************************
#include <msp430.h>
#include <stdint.h>
#include "hal_uart.h"

//****************************************************************************
// function
//****************************************************************************
void USER_halUARTA1Init(void)
{
    // Configure UART pins
	UARTA1TXD_PxSEL0 |= UARTA1TXD_PIN;         // set 2-UART pin as second function
	UARTA1RXD_PxSEL0 |= UARTA1RXD_PIN;

    // Configure UART
    UCA1CTLW0 |= UCSWRST;                     // Put eUSCI in reset
    UCA1CTLW0 |= UCSSEL__SMCLK;
    // Baud Rate calculation
    UCA1BR0 = 17;                              // 2000000/115200 = 17.36
    UCA1MCTLW = 0x4A00;                       // 2000000/115200 - INT(2000000/115200)=0.36
                                              // UCBRSx value = 0x4A (See UG)
    UCA1BR1 = 0;
}

void USER_halUARTA1SendMessage(uint16_t ui16message)
{
    uint8_t TXData[2];
    uint8_t i;
    TXData[0] = (uint8_t)ui16message;
    TXData[1] = (uint8_t)(ui16message>>8);
    UCA1CTLW0 &= ~UCSWRST;                    // enable eUSCI
    for (i = 0; i < 2; i++)
    {
        while(!(UCA1IFG & UCTXIFG));
        UCA1TXBUF = TXData[i];
    }
    //while(!(UCA1IFG & UCTXIFG));
    //UCA1CTLW0 |= UCSWRST;                     // disable eUSCI
}



//****************************************************************************
// the END
//****************************************************************************
