/* --COPYRIGHT--,BSD
 * Copyright (c) 2016, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * --/COPYRIGHT--*/
//############################################################################
//
//! \file   touch.c
//!
//! \brief  user application for touch buttons, slider, proximity and
//! \       centralpad
//
//  Target Device:  MSP430FR2633
//
//  Created on: July, 2015
//  Author: a0222599
//############################################################################
//****************************************************************************
// the includes
//****************************************************************************
#include "touch.h"
#include "user_command.h"
#include "hal_timer.h"
#include "hal_led.h"

#include "captivate.h"

//****************************************************************************
//globals
//****************************************************************************
touchEventParams touchEvent=
{
    .ui16PrevTouchEventID = NO_TOUCH,
    .ui16PrevTouchEventTime = 0,
    .ui16CurrentTouchEventID = NO_TOUCH,
    .ui16CurrentTouchEventTime = 0,
    .ui16RealTouchEvent = NO_TOUCH,
};

uint16_t ui16touchID_Button[]=
{INT_BUTTON_00, INT_BUTTON_01, INT_BUTTON_02, INT_BUTTON_03, INT_BUTTON_04,
    INT_BUTTON_05, INT_BUTTON_06, INT_BUTTON_07};

bool bProx_ProxPad = false;

uint16_t ui16sliderContinuousCycle = 0;

//****************************************************************************
// function
//****************************************************************************
void USER_callbackButtons(tSensor* pSensor)
{
    uint16_t ui16DominantButton;
    if((pSensor->bSensorTouch == true) && (pSensor->bSensorPrevTouch == false))
    {
        ui16DominantButton = ((tButtonSensorParams*)(pSensor->pSensorParams))->ui16DominantElement;
        USER_TouchEventHandler(ui16touchID_Button[ui16DominantButton]);
    }

}// end of Buttons_callback(tSensor* pSensor) function

void USER_callbackProxPad(tSensor* pSensor)
{
    //uint16_t temp_command;
    //temp_command = PROXPAD_WAKEUP;
    //USER_sendCommand(temp_command);
	if(pSensor->bSensorProx == true)
	{
//	    if((pSensor->bSensorTouch == true) && (pSensor->bSensorPrevTouch == false))
//	    {
	    	if(bProx_ProxPad == false)
	    	{
                //temp_command = PROXPAD_HOLD;
                //USER_sendCommand(temp_command);
	            LED_GREEN_ON;
	            __delay_cycles(2500000);
	            LED_GREEN_OFF;
	    	}
	    	bProx_ProxPad = true;
//	    }
	}
	else
	{
//        if(bProx_ProxPad == true)
//        {
            bProx_ProxPad = false;
//        temp_command = PROXPAD_NULL;
//        USER_sendCommand(temp_command);
//        }

	}

}// end of USER_callbackProxPad(tSensor* pSensor) function

void USER_callbackaSlider(tSensor* pSensor)
{
    tSliderSensorParams *pSliderParams;
    if(pSensor->bSensorTouch == true)
    //if((pSensor->bSensorTouch == true)  && (pSensor->bSensorPrevTouch == false))
    {
        pSliderParams = (tSliderSensorParams*)(pSensor->pSensorParams);
        if(pSliderParams->SliderPosition.ui16Natural <= INT_SLIDER_TOP)
        {
            USER_TouchEventHandler(pSliderParams->SliderPosition.ui16Natural);
        }
#ifdef  SLIDER_VOL_STEP_CYCLE
        if((ui16sliderContinuousCycle++) >= SLIDER_VOL_STEP_CYCLE)
        {
            ui16sliderContinuousCycle = 0;
        }
#endif
    }
    else
    {
        ui16sliderContinuousCycle = 0;
    }
}// end of aINT_SLIDER_callback(tSensor* pSensor) function

void USER_TouchEventHandler(uint16_t touchID)
{
    bool bIgnoreCommand = false;
    touchEvent.ui16CurrentTouchEventID = touchID;
    if(USER_analyseTouchEvent())
    {
        if((touchEvent.ui16RealTouchEvent&INT_SLIDER_STEP_COMMAND) == INT_SLIDER_STEP_COMMAND)
        {
            if(ui16sliderContinuousCycle != 0)
            {
                bIgnoreCommand = true;
            }
        }

        if(!bIgnoreCommand)
        {
            USER_sendCommand(touchEvent.ui16RealTouchEvent);
        }
        touchEvent.ui16RealTouchEvent = NO_TOUCH;
    }
    else;
    touchEvent.ui16PrevTouchEventID = touchEvent.ui16CurrentTouchEventID;
    touchEvent.ui16PrevTouchEventTime = touchEvent.ui16CurrentTouchEventTime;
    touchEvent.ui16CurrentTouchEventID = NO_TOUCH;
    touchEvent.ui16CurrentTouchEventTime = 0;

}//end of function USER_TouchEventHandler(uint16_t touchID)

bool USER_analyseTouchEvent(void)
{
    uint16_t period;
    uint16_t currentTouchID = touchEvent.ui16CurrentTouchEventID;
    uint16_t prevTouchID = touchEvent.ui16PrevTouchEventID;
    //Button power function
    if(currentTouchID == INT_BUTTON_04)
    {
        if(prevTouchID != INT_BUTTON_04)
        {
            touchEvent.ui16CurrentTouchEventTime = USER_halTimer2Start();
            touchEvent.ui16RealTouchEvent = BUTTON_POWER;
        }
        else
        {
            touchEvent.ui16CurrentTouchEventTime = USER_halTimer2Stop();
            period = touchEvent.ui16CurrentTouchEventTime - touchEvent.ui16PrevTouchEventTime;
            if(period >= BUTTON_POWER_PERIOD)
            {
                touchEvent.ui16RealTouchEvent = BUTTON_POWER;
            }
            touchEvent.ui16CurrentTouchEventTime = USER_halTimer2Start();
        }
    }
    //Button touch function
    else if((currentTouchID == INT_BUTTON_00)||(currentTouchID == INT_BUTTON_01)
        ||(currentTouchID == INT_BUTTON_02)||(currentTouchID == INT_BUTTON_03)
        ||(currentTouchID == INT_BUTTON_05)||(currentTouchID == INT_BUTTON_06)
        ||(currentTouchID == INT_BUTTON_07))
    {
        if(currentTouchID != prevTouchID)
            {
                touchEvent.ui16CurrentTouchEventTime = USER_halTimer2Start();
                touchEvent.ui16RealTouchEvent = currentTouchID;
            }
        else
        {
            touchEvent.ui16CurrentTouchEventTime = USER_halTimer2Stop();
            period = touchEvent.ui16CurrentTouchEventTime - touchEvent.ui16PrevTouchEventTime;
            if(period >= BUTTON_TOUCH_PERIOD)
            {
                touchEvent.ui16RealTouchEvent = currentTouchID;
            }
            touchEvent.ui16CurrentTouchEventTime = USER_halTimer2Start();
        }
    }
    //Slider function
#ifdef  SLIDER_VOL_STEP_CYCLE
    else if(currentTouchID <= INT_SLIDER_TOP)
    {
        if((currentTouchID > INT_SLIDER_00)&&(currentTouchID < INT_SLIDER_10))
        {
            touchEvent.ui16RealTouchEvent = SLIDER_VOL_DOWN_05;
        }
        else if((currentTouchID >= INT_SLIDER_10)&&(currentTouchID < INT_SLIDER_20))
        {
            touchEvent.ui16RealTouchEvent = SLIDER_VOL_DOWN_04;
        }
        else if((currentTouchID >= INT_SLIDER_20)&&(currentTouchID < INT_SLIDER_30))
        {
            touchEvent.ui16RealTouchEvent = SLIDER_VOL_DOWN_03;
        }
        else if((currentTouchID >= INT_SLIDER_30)&&(currentTouchID < INT_SLIDER_40))
        {
            touchEvent.ui16RealTouchEvent = SLIDER_VOL_DOWN_02;
        }
        else if((currentTouchID >= INT_SLIDER_40)&&(currentTouchID < INT_SLIDER_50))
        {
            touchEvent.ui16RealTouchEvent = SLIDER_VOL_DOWN_01;
        }
        else if((currentTouchID > INT_SLIDER_50)&&(currentTouchID <= INT_SLIDER_60))
        {
            touchEvent.ui16RealTouchEvent = SLIDER_VOL_UP_01;
        }
        else if((currentTouchID > INT_SLIDER_60)&&(currentTouchID <= INT_SLIDER_70))
        {
            touchEvent.ui16RealTouchEvent = SLIDER_VOL_UP_02;
        }
        else if((currentTouchID > INT_SLIDER_70)&&(currentTouchID <= INT_SLIDER_80))
        {
            touchEvent.ui16RealTouchEvent = SLIDER_VOL_UP_03;
        }
        else if((currentTouchID > INT_SLIDER_80)&&(currentTouchID <= INT_SLIDER_90))
        {
            touchEvent.ui16RealTouchEvent = SLIDER_VOL_UP_04;
        }
        else if((currentTouchID > INT_SLIDER_90)&&(currentTouchID <= INT_SLIDER_100))
        {
            touchEvent.ui16RealTouchEvent = SLIDER_VOL_UP_05;
        }
        else if(currentTouchID == INT_SLIDER_50)
        {
            touchEvent.ui16RealTouchEvent = SLIDER_VOL_STOP;
        }
    }
#else
    else if(currentTouchID <= INT_SLIDER_TOP)
    {
        touchEvent.ui16RealTouchEvent = (currentTouchID + SLIDER_VOL_CONTI_BASE);
    }
#endif
    else;

    if(touchEvent.ui16RealTouchEvent == NO_TOUCH)
    {
        return false;
    }
    else
    {
        return true;
    }

}//end of function USER_analyseTouchEvent(void)

void USER_cleanTouchHistory(void)
{
    touchEvent.ui16PrevTouchEventID = NO_TOUCH;
    touchEvent.ui16PrevTouchEventTime = 0;
}
//****************************************************************************
// the END
//****************************************************************************
