/* --COPYRIGHT--,BSD
 * Copyright (c) 2016, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * --/COPYRIGHT--*/
//############################################################################
//
//! \file   touch.h
//!
//! \brief  Driver for the touch functions
//
//  Target Device:  MSP430FR2633
//
//  Created on: July, 2015
//  Author: a0222599
//############################################################################
#ifndef __TOUCH_H__
#define __TOUCH_H__

//****************************************************************************
// the includes
//****************************************************************************
#include <msp430.h>
#include <captivate.h>           // CapTIvate Touch Software Library
#include "CAPT_UserConfig.h"     // CapTIvate Auto-Generated User Configuration

//****************************************************************************
//
// If building with a C++ compiler, make all of the definitions in this header
// have a C binding.
//
//****************************************************************************
#ifdef __cplusplus
extern "C"
{
#endif

//****************************************************************************
//defines
//****************************************************************************
//! \basic touch ID for "Element Exx"
//!
#define  CENTRALPAD_SLIDERHOLD_PERIOD  (8192)  // 0.5s
#define  CENTRALPAD_HOLD_PERIOD        (4096)  // 0.25s
#define  CENTRALPAD_ENTER_PERIOD       (8192)  // 0.5s
#define  BUTTON_POWER_PERIOD           (24576)  // 1.5s
#define  BUTTON_TOUCH_PERIOD           (8192)  // 0.5s

//#define  SLIDER_VOL_STEP_CYCLE         (15)// 0.5s in 30Hz scan rate

//! \basic touch ID for "Element Exx"
/**************     internal use    **************/
// Buttons
#define         NO_TOUCH                     (TOUCH_NULL)
#define         INT_BUTTON_04                (BUTTON_POWER)
#define         INT_BUTTON_00                (BUTTON_CHDOWN)
#define         INT_BUTTON_01                (BUTTON_CHUP)
#define         INT_BUTTON_02                (BUTTON_A)
#define         INT_BUTTON_03                (BUTTON_B)
#define         INT_BUTTON_05                (BUTTON_C)
#define         INT_BUTTON_06                (BUTTON_INPUT)
#define         INT_BUTTON_07                (BUTTON_MUTE)

// Slider
#define         INT_SLIDER_TOP               (100)
#define         INT_SLIDER_50                (50)
#define         INT_SLIDER_60                (60)
#define         INT_SLIDER_70                (70)
#define         INT_SLIDER_80                (80)
#define         INT_SLIDER_90                (90)
#define         INT_SLIDER_100               (100)
#define         INT_SLIDER_40                (40)
#define         INT_SLIDER_30                (30)
#define         INT_SLIDER_20                (20)
#define         INT_SLIDER_10                (10)
#define         INT_SLIDER_00                (1)

#define         INT_SLIDER_STEP_COMMAND      (0x0400)




//****************************************************************************
// typedefs
//****************************************************************************
//! \basic touch event
//!
typedef struct
{
    uint16_t   ui16PrevTouchEventID;   // global touch event ID on all touch sensors
    uint16_t   ui16PrevTouchEventTime;   // time of global touch event
    uint16_t   ui16CurrentTouchEventID;   // global touch event ID on all touch sensors
    uint16_t   ui16CurrentTouchEventTime;   // time of global touch event
    uint16_t   ui16RealTouchEvent;   // the real touch event
}
touchEventParams;

//****************************************************************************
//globals
//****************************************************************************
extern touchEventParams touchEvent;

extern uint16_t ui16touchID_Button[];

extern bool bProx_ProxPad;

extern uint16_t ui16sliderContinuousCycle;

//****************************************************************************
// the function prototypes
//****************************************************************************
//! \brief         Buttons callback
//! \param[in] tSensor* pSensor
extern void USER_callbackButtons(tSensor* pSensor);

//! \brief         Prox Pad callback
//! \param[in] tSensor* pSensor
extern void USER_callbackProxPad(tSensor* pSensor);

//! \brief         aSlider callback
//! \param[in] tSensor* pSensor
extern void USER_callbackaSlider(tSensor* pSensor);

//! \brief         touch event handler
//! \param[in]  uint16_t touchID
//!
extern void USER_TouchEventHandler(uint16_t touchID);

//! \brief         analyse the touch event
//! \param[in]  void
//!
extern bool USER_analyseTouchEvent(void);

//! \brief         clean up the touch history
//! \param[in]  void
//!
extern void USER_cleanTouchHistory(void);



//****************************************************************************
//
// Mark the end of the C bindings section for C++ compilers.
//
//****************************************************************************
#ifdef __cplusplus
}
#endif

#endif  // end of __TOUCH_H__ definition
